'use strict';

var RE = /{([\d,-]+)}/;
var index = (function (md) {
  var fence = md.renderer.rules.fence;

  md.renderer.rules.fence = function () {
    var args = [], len = arguments.length;
    while ( len-- ) args[ len ] = arguments[ len ];

    var tokens = args[0];
    var idx = args[1];
    var options = args[2];
    var ref = tokens[idx];
    var params = ref.params;
    var content = ref.content;

    if (!params || !RE.test(params)) {
      return fence.apply(void 0, args);
    }

    var lineNumbers = RE.exec(params)[1].split(',').map(function (v) { return v.split('-').map(function (v) { return parseInt(v, 10); }); });
    var langName = params.replace(RE, '').trim();
    var code = options.highlight ? options.highlight(content, langName) : content;
    var codeSplits = code.split('\n').map(function (split, index) {
      var lineNumber = index + 1;
      var inRange = lineNumbers.some(function (ref) {
        var start = ref[0];
        var end = ref[1];

        return start && end ? lineNumber >= start && lineNumber <= end : lineNumber === start;
      });
      return inRange ? {
        code: ("<span class=\"highlighted-line\">" + split + "</span>"),
        highlighted: true
      } : {
        code: split
      };
    });
    var highlightedCode = codeSplits.reduce(function (code, split) {
      code += split.highlighted ? split.code : ((split.code) + "\n");
      return code;
    }, ''); // If custom highlighter wraps code with starting <pre..., don't wrap code

    if (highlightedCode.startsWith('<pre')) {
      return highlightedCode;
    }

    return ("<pre><code " + (langName ? ("class=\"" + (options.langPrefix) + langName + "\"") : '') + ">" + (highlightedCode.trim()) + "</code></pre>");
  };
});

module.exports = index;
